@@ -1,17 +1,11 @@
-import ee
 import warnings
+
+import ee
+import ee_extra
+import ee_extra.Spectral.core
 import requests
-from .common import _index
-from .common import _maskClouds
-from .common import _get_scale_params
-from .common import _get_offset_params
-from .common import _scale_STAC
-from .common import _preprocess
-from .common import _getSTAC
-from .common import _getDOI
-from .common import _getCitation
-from .common import _panSharpen
-from .common import _matchHistogram
+
+from .common import _matchHistogram, _panSharpen
 from .extending import extend
 
 
@@ -24,8 +18,10 @@ def __getitem__(self, key):
     self : ee.Image
         Image to get the bands from.
     key : numeric | string | list[numeric] | list[string] | slice
-        Key used to get the specified band. If numeric, it gets the band at that index. If string, it gets the band with that name
-        or that matches with regex. If list, it gets multiple bands. If slice, it calls the slice() method (the step parameter is ignored).
+        Key used to get the specified band. If numeric, it gets the band at that index.
+        If string, it gets the band with that name or that matches with regex. If list, it
+        gets multiple bands. If slice, it calls the slice() method (the step parameter is
+        ignored).
 
     Returns
     -------
@@ -61,7 +57,8 @@ def __add__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -80,7 +77,8 @@ def __radd__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -99,7 +97,8 @@ def __sub__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -118,7 +117,8 @@ def __rsub__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -137,7 +137,8 @@ def __mul__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -156,7 +157,8 @@ def __rmul__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -175,7 +177,8 @@ def __truediv__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -194,7 +197,8 @@ def __rtruediv__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -213,7 +217,8 @@ def __floordiv__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -232,7 +237,8 @@ def __rfloordiv__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -251,7 +257,8 @@ def __mod__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -270,7 +277,8 @@ def __rmod__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -289,7 +297,8 @@ def __pow__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -308,7 +317,8 @@ def __rpow__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -327,7 +337,8 @@ def __lshift__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -346,7 +357,8 @@ def __rlshift__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -365,7 +377,8 @@ def __rshift__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -384,7 +397,8 @@ def __rrshift__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -403,7 +417,8 @@ def __and__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -422,7 +437,8 @@ def __rand__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -441,7 +457,8 @@ def __or__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -460,7 +477,8 @@ def __ror__(self, other):
     self : ee.Image
         Right operand.
     other : ee.Image | numeric | list[numeric]
-        Left operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Left operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -479,7 +497,8 @@ def __lt__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -498,7 +517,8 @@ def __le__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -517,7 +537,8 @@ def __eq__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -536,7 +557,8 @@ def __ne__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -555,7 +577,8 @@ def __gt__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -574,7 +597,8 @@ def __ge__(self, other):
     self : ee.Image
         Left operand.
     other : ee.Image | numeric | list[numeric]
-        Right operand. If numeric, an ee.Image is created from its value. If list, an ee.Image with n bands (n = len(list)) is created from its values.
+        Right operand. If numeric, an ee.Image is created from its value. If list, an
+        ee.Image with n bands (n = len(list)) is created from its values.
 
     Returns
     -------
@@ -631,21 +655,23 @@ def index(
     alpha=0.1,
     slope=1.0,
     intercept=0.0,
+    gamma=1.0,
     kernel="RBF",
     sigma="0.5 * (a + b)",
     p=2.0,
     c=1.0,
     online=False,
+    drop=False,
 ):
     """Computes one or more spectral indices (indices are added as bands) for an image.
 
-    Warning
-    -------------
-    **Pending Deprecation:** The :code:`index()` method will no longer be available for future versions. Please use :code:`spectralIndices()` instead.
+    .. deprecated:: 0.3.0
+       Use :func:`spectralIndices()` instead.
 
     Tip
     ----------
-    Check more info about the supported platforms and spectral indices in the :ref:`User Guide<Spectral Indices Computation>`.
+    Check more info about the supported platforms and spectral indices in the
+    :ref:`User Guide<Spectral Indices Computation>`.
 
     Parameters
     ----------
@@ -663,7 +689,8 @@ def index(
             - 'kernel' : Compute all kernel indices.
             - 'all' : Compute all indices listed below.
         Awesome Spectral Indices for GEE:
-            Check the complete list of indices `here <https://awesome-ee-spectral-indices.readthedocs.io/en/latest/list.html>`_.
+            Check the complete list of indices
+            `here <https://awesome-ee-spectral-indices.readthedocs.io/en/latest/list.html>`_.
     G : float, default = 2.5
         Gain factor. Used just for index = 'EVI'.
     C1 : float, default = 6.0
@@ -677,11 +704,13 @@ def index(
     nexp : float, default = 2.0
         Exponent used for GDVI.
     alpha : float, default = 0.1
-        Weighting coefficient  used for WDRVI.
+        Weighting coefficient used for WDRVI.
     slope : float, default = 1.0
         Soil line slope.
     intercept : float, default = 0.0
         Soil line intercept.
+    gamma : float, default = 1.0
+        Weighting coefficient used for ARVI.
     kernel : str, default = 'RBF'
         Kernel used for kernel indices.\n
         Available options:
@@ -689,16 +718,19 @@ def index(
             - 'RBF' : Radial Basis Function (RBF) Kernel.
             - 'poly' : Polynomial Kernel.
     sigma : str | float, default = '0.5 * (a + b)'
-        Length-scale parameter. Used for kernel = 'RBF'. If str, this must be an expression including 'a' and 'b'. If numeric, this must be positive.
+        Length-scale parameter. Used for kernel = 'RBF'. If str, this must be an
+        expression including 'a' and 'b'. If numeric, this must be positive.
     p : float, default = 2.0
         Kernel degree. Used for kernel = 'poly'.
     c : float, default = 1.0
-        Free parameter that trades off the influence of higher-order versus lower-order terms in the polynomial kernel.
-        Used for kernel = 'poly'. This must be greater than or equal to 0.
+        Free parameter that trades off the influence of higher-order versus lower-order
+        terms in the polynomial kernel. Used for kernel = 'poly'. This must be greater
+        than or equal to 0.
     online : boolean, default = False
-        Wheter to retrieve the most recent list of indices directly from the GitHub repository and not from the local copy.
-
-        .. versionadded:: 0.2.0
+        Wheter to retrieve the most recent list of indices directly from the GitHub
+        repository and not from the local copy.
+    drop : boolean, default = True
+        Whether to drop all bands except the new spectral indices.
 
     Returns
     -------
@@ -741,11 +773,11 @@ def index(
     >>> S2.index('all')
     """
     warnings.warn(
-        "index() will be deprecated in future versions, please use spectralIndices() instead",
-        PendingDeprecationWarning,
+        "index() is deprecated, please use spectralIndices() instead",
+        DeprecationWarning,
     )
 
-    return _index(
+    return ee_extra.Spectral.core.spectralIndices(
         self,
         index,
         G,
@@ -757,11 +789,13 @@ def index(
         alpha,
         slope,
         intercept,
+        gamma,
         kernel,
         sigma,
         p,
         c,
         online,
+        drop,
     )
 
 
@@ -778,17 +812,21 @@ def spectralIndices(
     alpha=0.1,
     slope=1.0,
     intercept=0.0,
+    gamma=1.0,
     kernel="RBF",
     sigma="0.5 * (a + b)",
     p=2.0,
     c=1.0,
     online=False,
+    drop=False,
 ):
-    """Computes one or more spectral indices (indices are added as bands) for an image from the Awesome List of Spectral Indices.
+    """Computes one or more spectral indices (indices are added as bands) for an image
+    from the Awesome List of Spectral Indices.
 
     Tip
     ----------
-    Check more info about the supported platforms and spectral indices in the :ref:`User Guide<Spectral Indices Computation>`.
+    Check more info about the supported platforms and spectral indices in the
+    :ref:`User Guide<Spectral Indices Computation>`.
 
     Parameters
     ----------
@@ -806,7 +844,8 @@ def spectralIndices(
             - 'kernel' : Compute all kernel indices.
             - 'all' : Compute all indices listed below.
         Awesome Spectral Indices for GEE:
-            Check the complete list of indices `here <https://awesome-ee-spectral-indices.readthedocs.io/en/latest/list.html>`_.
+            Check the complete list of indices
+            `here <https://awesome-ee-spectral-indices.readthedocs.io/en/latest/list.html>`_.
     G : float, default = 2.5
         Gain factor. Used just for index = 'EVI'.
     C1 : float, default = 6.0
@@ -820,11 +859,13 @@ def spectralIndices(
     nexp : float, default = 2.0
         Exponent used for GDVI.
     alpha : float, default = 0.1
-        Weighting coefficient  used for WDRVI.
+        Weighting coefficient used for WDRVI.
     slope : float, default = 1.0
         Soil line slope.
     intercept : float, default = 0.0
         Soil line intercept.
+    gamma : float, default = 1.0
+        Weighting coefficient used for ARVI.
     kernel : str, default = 'RBF'
         Kernel used for kernel indices.\n
         Available options:
@@ -832,14 +873,19 @@ def spectralIndices(
             - 'RBF' : Radial Basis Function (RBF) Kernel.
             - 'poly' : Polynomial Kernel.
     sigma : str | float, default = '0.5 * (a + b)'
-        Length-scale parameter. Used for kernel = 'RBF'. If str, this must be an expression including 'a' and 'b'. If numeric, this must be positive.
+        Length-scale parameter. Used for kernel = 'RBF'. If str, this must be an
+        expression including 'a' and 'b'. If numeric, this must be positive.
     p : float, default = 2.0
         Kernel degree. Used for kernel = 'poly'.
     c : float, default = 1.0
-        Free parameter that trades off the influence of higher-order versus lower-order terms in the polynomial kernel.
-        Used for kernel = 'poly'. This must be greater than or equal to 0.
+        Free parameter that trades off the influence of higher-order versus lower-order
+        terms in the polynomial kernel. Used for kernel = 'poly'. This must be greater
+        than or equal to 0.
     online : boolean, default = False
-        Wheter to retrieve the most recent list of indices directly from the GitHub repository and not from the local copy.
+        Wheter to retrieve the most recent list of indices directly from the GitHub
+        repository and not from the local copy.
+    drop : boolean, default = True
+        Whether to drop all bands except the new spectral indices.
 
     Returns
     -------
@@ -881,7 +927,7 @@ def spectralIndices(
 
     >>> S2.spectralIndices('all')
     """
-    return _index(
+    return ee_extra.Spectral.core.spectralIndices(
         self,
         index,
         G,
@@ -893,11 +939,13 @@ def spectralIndices(
         alpha,
         slope,
         intercept,
+        gamma,
         kernel,
         sigma,
         p,
         c,
         online,
+        drop,
     )
 
 
@@ -918,7 +966,8 @@ def maskClouds(
 
     Tip
     ----------
-    Check more info about the supported platforms and clouds masking in the :ref:`User Guide<Masking Clouds and Shadows>`.
+    Check more info about the supported platforms and clouds masking in the
+    :ref:`User Guide<Masking Clouds and Shadows>`.
 
     Parameters
     ----------
@@ -931,23 +980,32 @@ def maskClouds(
             - 'qa' : Use Quality Assessment band.
         This parameter is ignored for Landsat products.
     prob : numeric [0, 100], default = 60
-        Cloud probability threshold. Valid just for method = 'cloud_prob'. This parameter is ignored for Landsat products.
+        Cloud probability threshold. Valid just for method = 'cloud_prob'. This parameter
+        is ignored for Landsat products.
     maskCirrus : boolean, default = True
-        Whether to mask cirrus clouds. Valid just for method = 'qa'. This parameter is ignored for Landsat products.
+        Whether to mask cirrus clouds. Valid just for method = 'qa'. This parameter is
+        ignored for Landsat products.
     maskShadows : boolean, default = True
-        Whether to mask cloud shadows. For more info see 'Braaten, J. 2020. Sentinel-2 Cloud Masking with s2cloudless. Google Earth Engine, Community Tutorials'.
+        Whether to mask cloud shadows. For more info see 'Braaten, J. 2020. Sentinel-2
+        Cloud Masking with s2cloudless. Google Earth Engine, Community Tutorials'.
     scaledImage : boolean, default = False
-        Whether the pixel values are scaled to the range [0,1] (reflectance values). This parameter is ignored for Landsat products.
+        Whether the pixel values are scaled to the range [0,1] (reflectance values).
+        This parameter is ignored for Landsat products.
     dark : float [0,1], default = 0.15
-        NIR threshold. NIR values below this threshold are potential cloud shadows. This parameter is ignored for Landsat products.
+        NIR threshold. NIR values below this threshold are potential cloud shadows.
+        This parameter is ignored for Landsat products.
     cloudDist : int, default = 1000
-        Maximum distance in meters (m) to look for cloud shadows from cloud edges. This parameter is ignored for Landsat products.
+        Maximum distance in meters (m) to look for cloud shadows from cloud edges.
+        This parameter is ignored for Landsat products.
     buffer : int, default = 250
-        Distance in meters (m) to dilate cloud and cloud shadows objects. This parameter is ignored for Landsat products.
+        Distance in meters (m) to dilate cloud and cloud shadows objects. This parameter
+        is ignored for Landsat products.
     cdi : float [-1,1], default = None
-        Cloud Displacement Index threshold. Values below this threshold are considered potential clouds.
-        A cdi = None means that the index is not used. For more info see 'Frantz, D., HaS, E., Uhl, A., Stoffels, J., Hill, J. 2018. Improvement of the Fmask algorithm for Sentinel-2 images:
-        Separating clouds from bright surfaces based on parallax effects. Remote Sensing of Environment 2015: 471-481'.
+        Cloud Displacement Index threshold. Values below this threshold are considered
+        potential clouds. A cdi = None means that the index is not used. For more info see
+        'Frantz, D., HaS, E., Uhl, A., Stoffels, J., Hill, J. 2018. Improvement of the
+        Fmask algorithm for Sentinel-2 images: Separating clouds from bright surfaces
+        based on parallax effects. Remote Sensing of Environment 2015: 471-481'.
         This parameter is ignored for Landsat products.
 
     Returns
@@ -964,9 +1022,11 @@ def maskClouds(
     >>> import ee, eemont
     >>> ee.Authenticate()
     >>> ee.Initialize()
-    >>> S2 = ee.ImageCollection('COPERNICUS/S2_SR').first().maskClouds(prob = 75,buffer = 300,cdi = -0.5)
+    >>> S2 = (ee.ImageCollection('COPERNICUS/S2_SR')
+    ...     .first()
+    ...     .maskClouds(prob = 75,buffer = 300,cdi = -0.5))
     """
-    return _maskClouds(
+    return ee_extra.QA.clouds.maskClouds(
         self,
         method,
         prob,
@@ -984,13 +1044,13 @@ def maskClouds(
 def scale(self):
     """Scales bands on an image.
 
-    Warning
-    -------------
-    **Pending Deprecation:** The :code:`scale()` method will no longer be available for future versions. Please use :code:`scaleAndOffset()` instead.
+    .. deprecated:: 0.3.0
+       Use :func:`scaleAndOffset()` instead.
 
     Tip
     ----------
-    Check more info about the supported platforms and image scaling the :ref:`User Guide<Image Scaling>`.
+    Check more info about the supported platforms and image scaling the
+    :ref:`User Guide<Image Scaling>`.
 
     Parameters
     ----------
@@ -1010,11 +1070,11 @@ def scale(self):
     >>> S2 = ee.ImageCollection('COPERNICUS/S2_SR').first().scale()
     """
     warnings.warn(
-        "scale() will be deprecated in future versions, please use scaleAndOffset() instead",
-        PendingDeprecationWarning,
+        "scale() is deprecated, please use scaleAndOffset() instead",
+        DeprecationWarning,
     )
 
-    return _scale_STAC(self)
+    return ee_extra.STAC.core.scaleAndOffset(self)
 
 
 @extend(ee.image.Image)
@@ -1055,7 +1115,7 @@ def getScaleParams(self):
      'QC_Day': 1.0,
      'QC_Night': 1.0}
     """
-    return _get_scale_params(self)
+    return ee_extra.STAC.core.getScaleParams(self)
 
 
 @extend(ee.image.Image)
@@ -1096,7 +1156,7 @@ def getOffsetParams(self):
      'QC_Day': 0.0,
      'QC_Night': 0.0}
     """
-    return _get_offset_params(self)
+    return ee_extra.STAC.core.getOffsetParams(self)
 
 
 @extend(ee.image.Image)
@@ -1105,7 +1165,8 @@ def scaleAndOffset(self):
 
     Tip
     ----------
-    Check more info about the supported platforms and image scaling the :ref:`User Guide<Image Scaling>`.
+    Check more info about the supported platforms and image scaling the
+    :ref:`User Guide<Image Scaling>`.
 
     Parameters
     ----------
@@ -1129,7 +1190,7 @@ def scaleAndOffset(self):
     >>> ee.Initialize()
     >>> S2 = ee.ImageCollection('COPERNICUS/S2_SR').first().scaleAndOffset()
     """
-    return _scale_STAC(self)
+    return ee_extra.STAC.core.scaleAndOffset(self)
 
 
 @extend(ee.image.Image)
@@ -1138,7 +1199,8 @@ def preprocess(self, **kwargs):
 
     Tip
     ----------
-    Check more info here about the supported platforms, :ref:`Image Scaling<Image Scaling>` and :ref:`Masking Clouds and Shadows<Masking Clouds and Shadows>`.
+    Check more info here about the supported platforms, :ref:`Image Scaling<Image Scaling>`
+    and :ref:`Masking Clouds and Shadows<Masking Clouds and Shadows>`.
 
     Parameters
     ----------
@@ -1166,7 +1228,7 @@ def preprocess(self, **kwargs):
     >>> ee.Initialize()
     >>> S2 = ee.ImageCollection('COPERNICUS/S2_SR').first().preprocess()
     """
-    return _preprocess(self, **kwargs)
+    return ee_extra.QA.pipelines.preprocess(self, **kwargs)
 
 
 @extend(ee.image.Image)
@@ -1197,7 +1259,7 @@ def getSTAC(self):
      'gee:type': 'image_collection',
      ...}
     """
-    return _getSTAC(self)
+    return ee_extra.STAC.core.getSTAC(self)
 
 
 @extend(ee.image.Image)
@@ -1226,7 +1288,7 @@ def getDOI(self):
     >>> ee.ImageCollection('NASA/GPM_L3/IMERG_V06').first().getDOI()
     '10.5067/GPM/IMERG/3B-HH/06'
     """
-    return _getDOI(self)
+    return ee_extra.STAC.core.getDOI(self)
 
 
 @extend(ee.image.Image)
@@ -1255,36 +1317,42 @@ def getCitation(self):
     >>> ee.ImageCollection('NASA/GPM_L3/IMERG_V06').first().getCitation()
     'Huffman, G.J., E.F. Stocker, D.T. Bolvin, E.J. Nelkin, Jackson Tan (2019),
     GPM IMERG Final Precipitation L3 Half Hourly 0.1 degree x 0.1 degree V06, Greenbelt,
-    MD, Goddard Earth Sciences Data and Information Services Center (GES DISC), Accessed: [Data Access Date],
+    MD, Goddard Earth Sciences Data and Information Services Center (GES DISC),
+    Accessed: [Data Access Date],
     [doi:10.5067/GPM/IMERG/3B-HH/06](https://doi.org/10.5067/GPM/IMERG/3B-HH/06)'
     """
-    return _getCitation(self)
+    return ee_extra.STAC.core.getCitation(self)
 
 
 @extend(ee.image.Image)
 def panSharpen(self, method="SFIM", qa=None, **kwargs):
-    """Apply panchromatic sharpening to the Image. Optionally, run quality assessments between the original and
-    sharpened Image to measure spectral distortion and set results as properties of the sharpened Image.
+    """Apply panchromatic sharpening to the Image.
+
+    Optionally, run quality assessments between the original and sharpened Image to
+    measure spectral distortion and set results as properties of the sharpened Image.
 
     Parameters
     ----------
     self : ee.Image [this]
         Image to sharpen.
     method : str, default="SFIM"
-        The sharpening algorithm to apply. Current options are "SFIM" (Smoothing Filter-based Intensity Modulation),
-        "HPFA" (High Pass Filter Addition), "PCS" (Principal Component Substitution), and "SM" (simple mean). Different
-        sharpening methods will produce different quality sharpening results in different scenarios.
+        The sharpening algorithm to apply. Current options are "SFIM" (Smoothing
+        Filter-based Intensity Modulation), "HPFA" (High Pass Filter Addition), "PCS"
+        (Principal Component Substitution), and "SM" (simple mean). Different sharpening
+        methods will produce different quality sharpening results in different scenarios.
     qa : str | list, default=None
-        One or more optional quality assessment names to apply after sharpening, e.g. "MSE", "RASE", "UIQI", etc.
+        One or more optional quality assessment names to apply after sharpening,
+        e.g. "MSE", "RASE", "UIQI", etc.
     **kwargs :
-        Keyword arguments passed to ee.Image.reduceRegion() such as "geometry", "maxPixels", "bestEffort", etc. These
-        arguments are only used for PCS sharpening and quality assessments.
+        Keyword arguments passed to ee.Image.reduceRegion() such as "geometry",
+        "maxPixels", "bestEffort", etc. These arguments are only used for PCS sharpening
+        and quality assessments.
 
     Returns
     -------
     ee.Image
-        The Image with all sharpenable bands sharpened to the panchromatic resolution and quality assessments run and
-        set as properties.
+        The Image with all sharpenable bands sharpened to the panchromatic resolution and
+        quality assessments run and set as properties.
 
     Examples
     --------
@@ -1308,11 +1376,14 @@ def matchHistogram(self, target, bands, geometry=None, maxBuckets=256):
     target : ee.Image
         Image to match.
     bands : dict
-        A dictionary of band names to match, with source bands as keys and target bands as values.
+        A dictionary of band names to match, with source bands as keys and target bands as
+        values.
     geometry : ee.Geometry, default=None
-        The region to match histograms in that overlaps both images. If none is provided, the geometry of the source image will be used.
+        The region to match histograms in that overlaps both images. If none is provided,
+        the geometry of the source image will be used.
     maxBuckets : int, default=256
-        The maximum number of buckets to use when building histograms. Will be rounded to the nearest power of 2.
+        The maximum number of buckets to use when building histograms. Will be rounded to
+        the nearest power of 2.
 
     Returns
     -------
@@ -1334,3 +1405,65 @@ def matchHistogram(self, target, bands, geometry=None, maxBuckets=256):
     >>> matched = source.matchHistogram(target, bands)
     """
     return _matchHistogram(self, target, bands, geometry, maxBuckets)
+
+
+@extend(ee.image.Image)
+def tasseledCap(self):
+    """Calculates tasseled cap brightness, wetness, and greenness components.
+
+    Tasseled cap transformations are applied using coefficients published for these
+    supported platforms:
+
+    * Sentinel-2 MSI Level 1C [1]_
+    * Landsat 8 OLI TOA [2]_
+    * Landsat 7 ETM+ TOA [3]_
+    * Landsat 5 TM Raw DN [4]_
+    * Landsat 4 TM Raw DN [5]_
+    * Landsat 4 TM Surface Reflectance [6]_
+    * MODIS NBAR [7]_
+
+    Parameters
+    ----------
+    self : ee.Image
+        Image to calculate tasseled cap components for. Must belong to a supported
+        platform.
+
+    Returns
+    -------
+    ee.Image
+        Image with the tasseled cap components as new bands.
+
+    References
+    ----------
+    .. [1] Shi, T., & Xu, H. (2019). Derivation of Tasseled Cap Transformation
+        Coefficients for Sentinel-2 MSI At-Sensor Reflectance Data. IEEE Journal
+        of Selected Topics in Applied Earth Observations and Remote Sensing, 1–11.
+        doi:10.1109/jstars.2019.2938388
+    .. [2] Baig, M.H.A., Zhang, L., Shuai, T. and Tong, Q., 2014. Derivation of a
+        tasselled cap transformation based on Landsat 8 at-satellite reflectance.
+        Remote Sensing Letters, 5(5), pp.423-431.
+    .. [3] Huang, C., Wylie, B., Yang, L., Homer, C. and Zylstra, G., 2002.
+        Derivation of a tasselled cap transformation based on Landsat 7 at-satellite
+        reflectance. International journal of remote sensing, 23(8), pp.1741-1748.
+    .. [4] Crist, E.P., Laurin, R. and Cicone, R.C., 1986, September. Vegetation and
+        soils information contained in transformed Thematic Mapper data. In
+        Proceedings of IGARSS’86 symposium (pp. 1465-1470). Paris: European Space
+        Agency Publications Division.
+    .. [5] Crist, E.P. and Cicone, R.C., 1984. A physically-based transformation of
+        Thematic Mapper data---The TM Tasseled Cap. IEEE Transactions on Geoscience
+        and Remote sensing, (3), pp.256-263.
+    .. [6] Crist, E.P., 1985. A TM tasseled cap equivalent transformation for
+        reflectance factor data. Remote sensing of Environment, 17(3), pp.301-306.
+    .. [7] Lobser, S.E. and Cohen, W.B., 2007. MODIS tasselled cap: land cover
+        characteristics expressed through transformed MODIS data. International
+        Journal of Remote Sensing, 28(22), pp.5079-5101.
+
+    Examples
+    --------
+    >>> import ee, eemont
+    >>> ee.Authenticate()
+    >>> ee.Initialize()
+    >>> img = ee.Image("LANDSAT/LT05/C01/T1/LT05_044034_20081011")
+    >>> img = img.tasseledCap()
+    """
+    return ee_extra.Spectral.core.tasseledCap(self)
